# in_code_system

None

URI: https://w3id.org/linkml/tests/kitchen_sink/in_code_system



<!-- no inheritance hierarchy -->


## Properties

 * Range: CodeSystem

## Identifier and Mapping Information


